@@ -7,19 +7,37 @@ from oarepo_model_builder.stack import ReplaceElement, ModelBuilderStack
 from oarepo_model_builder.utils.deepmerge import deepmerge
 
 
-def titles_gen(supported_langs, key):
+def alternative_gen(supported_langs, key):
     data = {}
     for lan in supported_langs:
         alt = {key + '_' + lan: {
-            'type': 'fulltext+keyword'
+            'type': 'fulltext+keyword',
         }}
+        multilang_options = {}
+
+        if 'text' in supported_langs[lan]:
+            deepmerge(multilang_options, supported_langs[lan]['text'])
+
+        if 'sort' in supported_langs[lan]:
+            sort = deepmerge(supported_langs[lan]['sort'], {'index': False, 'language': lan})
+            deepmerge(multilang_options, {'sort': sort})
+
+        if 'keyword' in supported_langs[lan]:
+            deepmerge(multilang_options, {'fields': {'keyword': supported_langs[lan]['keyword']}})
+        deepmerge(
+            alt[key + '_' + lan].setdefault("oarepo:mapping", {}),
+            multilang_options,
+            [],
+        )
+
         data = deepmerge(data, alt)
+
     return data
 
 
 class MultilangPreprocessor(PropertyPreprocessor):
 
-    @process(model_builder=[JSONSchemaBuilder, InvenioScriptSampleDataBuilder],
+    @process(model_builder=JSONSchemaBuilder,
              path='**/properties/*',
              condition=lambda current, stack: current.type == 'multilingual')
     def modify_multilang_schema(self, data, stack: ModelBuilderStack, **kwargs):
@@ -34,6 +52,7 @@ class MultilangPreprocessor(PropertyPreprocessor):
                     'type': 'string'
                 }
             }
+
         }
         return data
 
@@ -41,7 +60,8 @@ class MultilangPreprocessor(PropertyPreprocessor):
              path='**/properties/*',
              condition=lambda current, stack: current.type == 'multilingual')
     def modify_multilang_mapping(self, data, stack: ModelBuilderStack, **kwargs):
-        alternative = titles_gen(self.settings.supported_langs, stack.top.key)
+        print('path', stack.path.split('/')[3:])
+        alternative = alternative_gen(self.settings.supported_langs, stack.top.key)
 
         data = {
             stack.top.key: {
@@ -67,11 +87,8 @@ class MultilangPreprocessor(PropertyPreprocessor):
     def modify_multilang_marshmallow(self, data, stack: ModelBuilderStack, **kwargs):
         data['type'] = 'object'
         deepmerge(data.setdefault('oarepo:marshmallow', {}), {
-            'imports': [{
-                'import': 'oarepo_model_builder_multilingual.schema',
-                'alias': 'multilingual'
-            }],
-            'class': 'multilingual.MultilingualSchema',
+            'class': self.settings.python.multilingual_schema_class,
             'list_nested': True
         })
+
         return data
